@@ -1,9 +1,10 @@
-__version__ = '0.1.2'
+__version__ = '0.1.5'
 
 from .detection import candidate_thresholds, median_areas, initial_threshold
 from .correction import corrected
 from .separation import separated
+from .utils import svs2dask_array
 
 __all__ = ['candidate_thresholds', 'median_areas', 'initial_threshold',
            'corrected', 'classify_contours', 'correct_mask',
-           'separated']
+           'separated', 'svs2dask_array']
