@@ -34,11 +34,7 @@ def get_hematoxylin(rgb):
     return arr_hema
 
 
-def candidate_thresholds(image):
-    # load image to array
-    # [10000:12000, 10000:12000]
-    img = utils.svs2dask_array(image)[10000:12000, 10000:12000]
-
+def candidate_thresholds(img):
     # convert image to grayscale (eliminate hue + saturation, retain luminance)
     @dask.delayed(pure=True)
     def get_grayscale(rgb):
